@@ -26,12 +26,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-class ForumAdmin extends Error {
+class ForumAdmin extends FFError {
 	var $group_id;
 	var $p,$g;
 
 	function __construct($group_id) {
-		$this->Error();
+		parent::__construct();
 		$this->group_id = $group_id;
 		if ($group_id) {
 			$this->group_id = $group_id;
