@@ -32,7 +32,7 @@ require_once $gfwww.'search/include/SearchManager.class.php';
  * always tries to be as generic as possible so that it can easily be
  * styled via CSS.
  */
-class Navigation extends Error {
+class Navigation extends FFError {
 	/**
 	 * Associative array of data for the project menus.
 	 *
@@ -44,7 +44,7 @@ class Navigation extends Error {
 	 * Constructor
 	 */
 	function Navigation() {
-		$this->Error();
+		parent::__construct();
 		return true;
 	}
 
@@ -103,15 +103,12 @@ class Navigation extends Error {
 			$res['urls'] = array();
 
 			$res['titles'][] = forge_get_config ('forge_name').' - Project News Highlights RSS';
-			$res['urls'][] = util_make_uri('/export/rss_sfnews.php');
-
-			$res['titles'][] = forge_get_config ('forge_name').' - Project News Highlights RSS 2.0';
 			$res['urls'][] = util_make_uri('/export/rss20_news.php');
 
 			$res['titles'][] = forge_get_config ('forge_name').' - New Projects RSS';
-			$res['urls'][] = util_make_uri('/export/rss_sfprojects.php');
+			$res['urls'][] = util_make_uri('/export/rss20_projects.php');
 
-			if (isset($GLOBALS['group_id'])) {
+			if (isset($GLOBALS['group_id']) && $GLOBALS['group_id'] > 0) {
 				$res['titles'][] = forge_get_config ('forge_name') . ' - New Activity RSS';
 				$res['urls'][] = util_make_uri('/export/rss20_activity.php?group_id='.$GLOBALS['group_id']);
 			}
