@@ -192,6 +192,17 @@ function &user_get_all_users() {
 	return user_get_objects (util_result_column_to_array($res,0)) ;
 }
 
+
+function filter_users_by_read_access($users) {
+	$filteredusers = array();
+	foreach ($users as $u) {
+		if ($u->getID() == user_getid() || forge_check_global_perm('forge_admin')) {
+			$filteredusers[] = $u;
+		}
+	}
+	return $filteredusers;
+}
+
 class GFUser extends FFError {
 	/**
 	 * Associative array of data from db.
