@@ -346,10 +346,8 @@ function session_cookie($name, $value, $domain='', $expiration=0) {
 	if ($expiration) {
 		$expiration = time() + $expiration;
 	}
-	/* evolvis: force secure (SSL-only) session cookies */
-	//$force_secure = true;
-	/* not (yet?) in FusionForge */
-	$force_secure = false;
+	/* force secure (SSL-only) session cookies if relevant */
+	$force_secure = forge_get_config('use_ssl');
 	if ($force_secure && !session_issecure()) {
 		return;
 	}
@@ -757,6 +755,11 @@ function session_continue($sessionKey) {
 	return true;
 }
 
+function session_refresh() {
+	$params = array();
+	plugin_hook('refresh_auth_session', $params);
+}
+
 function setup_tz_from_context() {
 	$user = session_get_user();
 	if (!is_object($user) || $user->isError()) {
