@@ -384,7 +384,7 @@ class ContribTrackerLegalStructure extends FFError {
 	var $data_array ;
 
 	function ContribTrackerLegalStructure ($id=false) {
-		$this->Error () ;
+		$this->FFError () ;
 		if (!$id) {
 			return true ;
 		}
@@ -488,7 +488,7 @@ class ContribTrackerActor extends FFError {
 	var $data_array ;
 
 	function ContribTrackerActor ($id=false) {
-		$this->Error () ;
+		$this->FFError () ;
 		if (!$id) {
 			return true ;
 		}
@@ -625,7 +625,7 @@ class ContribTrackerContribution extends FFError {
 	var $data_array ;
 
 	function ContribTrackerContribution ($id=false) {
-		$this->Error () ;
+		$this->FFError () ;
 		if (!$id) {
 			return true ;
 		}
@@ -762,7 +762,7 @@ class ContribTrackerParticipation extends FFError {
 	var $data_array ;
 
 	function ContribTrackerParticipation ($id=false) {
-		$this->Error () ;
+		$this->FFError () ;
 		if (!$id) {
 			return true ;
 		}
