@@ -1,8 +1,10 @@
-#! /bin/sh
+#!/bin/bash
 # Configure Subversion
 
 set -e
 
+source $(forge_get_config source_path)/post-install.d/common/service.inc
+
 if [ $(id -u) != 0 ] ; then
     echo "You must be root to run this"
 fi
