@@ -5,7 +5,7 @@
  * Copyright 2003-2010, Roland Mas, Franck Villaume
  * Copyright 2004, GForge, LLC
  * Copyright 2010, Alain Peyrat <aljeux@free.fr>
- * Copyright 2012-2014, Franck Villaume - TrivialDev
+ * Copyright 2012-2014,2016, Franck Villaume - TrivialDev
  * Copyright 2013, French Ministry of National Education
  *
  * This file is part of FusionForge.
@@ -290,10 +290,13 @@ some control over it to the project's administrator.");
 				return false;
 			}
 			system ("sed -i '/enable-rep-sharing = false/s/^. //' $repo/db/fsfs.conf") ;
-			// dav/ directory is required by old svn clients (eg. svn 1.6.17 on ubuntu 12.04)
+			// dav/ and dav/activities.d directories are required by old svn clients (eg. svn 1.6.17 on ubuntu 12.04)
 			if (!is_dir ("$repo/dav")) {
 				mkdir("$repo/dav");
 			}
+			if (!is_dir ("$repo/dav/activities.d")) {
+				mkdir("$repo/dav/activities.d");
+			}
 			system ("svn mkdir -m'Init' file:///$repo/trunk file:///$repo/tags file:///$repo/branches >/dev/null") ;
 			system ("find $repo -type d -print0 | xargs -r -0 chmod g+s") ;
 			// Allow read/write users to modify the SVN repository
@@ -554,6 +557,15 @@ some control over it to the project's administrator.");
 		global $last_user, $last_time, $last_tag, $time_ok, $start_time, $end_time,
 			$adds, $deletes, $updates, $commits, $date_key,
 			$messages, $last_message, $times, $revisions, $users, $xml_parser;
+		$commits = 0;
+		$adds = 0;
+		$updates = 0;
+		$deletes = 0;
+		$users = array();
+		$messages = array();
+		$times = array();
+		$revisions = array();
+
 		$group_id = $params['group'];
 		$project = group_get_object($group_id);
 		if (! $project->usesPlugin($this->name)) {
@@ -563,18 +575,23 @@ some control over it to the project's administrator.");
 		if (in_array('scmsvn', $params['show']) || (count($params['show']) < 1)) {
 			$start_time = $params['begin'];
 			$end_time = $params['end'];
-			
+
 			$xml_parser = xml_parser_create();
 			xml_set_element_handler($xml_parser, "SVNPluginStartElement", "SVNPluginEndElement");
 			xml_set_character_data_handler($xml_parser, "SVNPluginCharData");
 
 			// Grab&parse commit log
 			$protocol = forge_get_config('use_ssl', 'scmsvn') ? 'https://' : 'http://';
-			$u = session_get_user();
-			if ($project->enableAnonSCM())
+			if ($project->enableAnonSCM()) {
 				$server_script = '/anonscm/svnlog';
-			else
-				$server_script = '/authscm/'.$u->getUnixName().'/svnlog';
+			} else {
+				$u = session_get_user();
+				if ($u && !$u->isError()) {
+					$server_script = '/authscm/'.$u->getUnixName().'/svnlog';
+				} else {
+					return false;
+				}
+			}
 			$script_url = $protocol . forge_get_config('scm_host')
 				. $server_script
 				.'?unix_group_name='.$project->getUnixName()
