@@ -187,7 +187,7 @@ $server->register(
 //get user objects for array of user_ids
 function &getUsers($session_ser,$user_ids) {
 	continue_session($session_ser);
-	$users = user_get_objects($user_ids);
+	$users = filter_users_by_read_access(user_get_objects($user_ids));
 	if (!$users) {
 		return new soap_fault ('3001','user','Could Not Get Users By Id','Could Not Get Users By Id');
 	}
@@ -198,7 +198,7 @@ function &getUsers($session_ser,$user_ids) {
 //get active user objects
 function getActiveUsers($session_ser) {
 	continue_session($session_ser);
-	$users = user_get_active_users();
+	$users = filter_users_by_read_access(user_get_active_users());
 	if (!$users) {
 		return new soap_fault ('3001','getActiveUsers','Could Not Get Forge Users','Could Not Get Forge Users');
 	}
@@ -212,7 +212,10 @@ function getGroupUsers($session_ser, $group_id) {
 
 	$group = group_get_object($group_id);
 
-	if (!$group || !is_object($group)) {
+	if (!forge_check_perm ('project_read', $group_id)) {
+		$errMsg = 'Permission denied';
+		return new soap_fault ('3002','getGroupUsers',$errMsg,$errMsg);
+	} elseif (!$group || !is_object($group)) {
 		$errMsg = 'Could not get group: '.$group->getErrorMessage();
 		return new soap_fault ('3002','getGroupUsers',$errMsg,$errMsg);
 	} elseif ($group->isError()) {
@@ -231,7 +234,7 @@ function getGroupUsers($session_ser, $group_id) {
 //get user objects for array of unix_names
 function getUsersByName($session_ser,$user_names) {
 	continue_session($session_ser);
-	$usrs = user_get_objects_by_name($user_names);
+	$usrs = filter_users_by_read_access(user_get_objects_by_name($user_names));
 	if (!$usrs) {
 		return new soap_fault ('3002','user','Could Not Get Users By Name','Could Not Get Users By Name');
 	}
@@ -257,7 +260,7 @@ function addUser($unix_name,$firstname,$lastname,$password1,$password2,$email,
 function updateUser ($session_ser,$user_id,$firstname,$lastname,$language_id,$timezone,$mail_site,$mail_va,$use_ratings,$jabber_address,$jabber_only,$theme_id,$address,$address2,$phone,$fax,$title,$ccode){
 	continue_session($session_ser);
 	$user = user_get_object($user_id);
-	if (!$user || !is_object($user)) {
+	if (!$user || !is_object($user) || !($u->getID() == user_getid() || forge_check_global_perm('forge_admin'))) {
 		return new soap_fault ('updateUser','Could Not Get User','Could Not Get User');
 	}
 
@@ -272,7 +275,7 @@ function updateUser ($session_ser,$user_id,$firstname,$lastname,$language_id,$ti
 function deleteUser ($session_ser,$user_id){
 	continue_session($session_ser);
 	$user = user_get_object($user_id);
-	if (!$user || !is_object($user)) {
+	if (!$user || !is_object($user) || !forge_check_global_perm('forge_admin')) {
 		return new soap_fault ('deleteUser','Could Not Get User','Could Not Get User');
 	}elseif ($user->isError()){
 		return new soap_fault ('deleteUser',$user->getErrorMessage(),$user->getErrorMessage());
@@ -289,7 +292,7 @@ function deleteUser ($session_ser,$user_id){
 function changeStatus ($session_ser,$user_id,$status){
 	continue_session($session_ser);
 	$user = user_get_object($user_id);
-	if (!$user || !is_object($user)) {
+	if (!$user || !is_object($user) || !forge_check_global_perm('forge_admin')) {
 		return new soap_fault ('changeStatus','Could Not Get User','Could Not Get User');
 	}elseif ($user->isError()){
 		return new soap_fault ('changeStatus',$user->getErrorMessage(),$user->getErrorMessage());
@@ -306,7 +309,7 @@ function changeStatus ($session_ser,$user_id,$status){
 function changePassword ($session_ser,$user_id,$password){
 	continue_session($session_ser);
 	$user = user_get_object($user_id);
-	if (!$user || !is_object($user)) {
+	if (!$user || !is_object($user) || !($u->getID() == user_getid() || forge_check_global_perm('forge_admin'))) {
 		return new soap_fault ('changePassword','Could Not Get User','Could Not Get User');
 	}elseif ($user->isError()){
 		return new soap_fault ('changePassword',$user->getErrorMessage(),$user->getErrorMessage());
@@ -323,7 +326,7 @@ function changePassword ($session_ser,$user_id,$password){
 function &userGetGroups($session_ser,$user_id) {
 	continue_session($session_ser);
 	$user = user_get_object($user_id);
-	if (!$user) {
+	if (!$user || !is_object($user) || !($u->getID() == user_getid() || forge_check_global_perm('forge_admin'))) {
 		return new soap_fault ('3003','user','Could Not Get Users Projects','Could Not Get Users Projects');
 	}
 	return groups_to_soap($user->getGroups());
